@@ -31,7 +31,7 @@ Fsdb - a flat-text database for shell scripting
 
 
 =cut
-our $VERSION = '2.26';
+our $VERSION = '2.27';
 
 =head1 SYNOPSIS
 
@@ -231,21 +231,34 @@ L<http://www.isi.edu/~johnh/SOFTWARE/FSDB/index.html>.
 
 =head1 WHAT'S NEW
 
-=head2 2.26, 2011-12-12
-Bug fixes, particularly for perl-5.14.2.
+=head2 2.27, 2012-11-15
+Accumulated bug fixes.
 
 =over 4
 
-=item BUG FIX
+=item IMPROVEMENT
 
-Bugs fixed in L<Fsdb::IO::Reader(3)> manual page.
+F<csv_to_db> now reports errors in CVS input with real diagnostics.
+
+=item IMPROVEMENT
+
+F<dbcolmovingstats> can now compute median, when given the C<-m> option.
 
 =item BUG FIX
 
-Fixed problems where L<dbcolstats> was truncating floating point numbers
-when sorting.  This strange behavior happenes as of perl-5.14.2 and
-it I<seems> like a Perl bug.  I've worked around it for the test suites,
-but I'm a bit nervous.
+F<dbcolmovingstats> non-numeric handling (the C<-a> option) now works properly.
+
+=item DOCUMENTATION
+
+The internal
+F<t/test_command.t> test framework
+is now documented.
+
+=item BUG FIX
+
+F<dbrowuniq> now corretly handles the case where there is no input
+(previously it output a blank line, which is a malformed fsdb file).
+Thanks to Yuri Pradkin for reporting this bug.
 
 =back
 
@@ -1108,6 +1121,9 @@ Jerry Zhao F<zhaoy@isi.edu>,
 Ning Xu F<nxu@aludra.usc.edu>,
 Martin Lukac F<mlukac@lecs.cs.ucla.edu>.
 
+In addition, bugs have been reported by:
+Yuri Pradkin.
+
 Fsdb includes datasets contributed from NIST (DATA/nist_zarr13.fsdb),
 from
 L<http://www.itl.nist.gov/div898/handbook/eda/section4/eda4281.htm>,
@@ -2374,6 +2390,25 @@ correponding to the same entity into a single row with multiple columns.
 
 =back
 
+=head2 2.26, 2011-12-12
+Bug fixes, particularly for perl-5.14.2.
+
+=over 4
+
+=item BUG FIX
+
+Bugs fixed in L<Fsdb::IO::Reader(3)> manual page.
+
+=item BUG FIX
+
+Fixed problems where L<dbcolstats> was truncating floating point numbers
+when sorting.  This strange behavior happenes as of perl-5.14.2 and
+it I<seems> like a Perl bug.  I've worked around it for the test suites,
+but I'm a bit nervous.
+
+=back
+
+
 =head1 AUTHOR
 
 John Heidemann, C<johnh@isi.edu>
