@@ -2,7 +2,7 @@
 
 #
 # dbrowuniq.pm
-# Copyright (C) 1997-2008 by John Heidemann <johnh@isi.edu>
+# Copyright (C) 1997-2012 by John Heidemann <johnh@isi.edu>
 # $Id$
 #
 # This program is distributed under terms of the GNU general
@@ -26,10 +26,18 @@ Eliminate adjacent rows with duplicate fields, perhaps counting them.
 Roughly equivalent to the Unix L<uniq> command,
 but optionally only operating on the specified fields.
 
-By default, all columns must be unique.
+By default, I<all> columns must be unique.
 If column names are specified, only those columns must be unique
 and the first row with those columns is returned.
 
+Dbrowuniq eliminates only identical rows that I<adjacent>.
+If you want to eliminate identical rows across the entirefile,
+you must make them adajcent, perhaps by using dbsort on your
+uniquifying field.
+(That is, the input with three lines a/b/a will produce
+three lines of output with both a's, but if you dbsort it,
+it will become a/a/b and dbrowuniq will output a/b.
+
 =head1 OPTIONS
 
 =over 4
@@ -259,7 +267,7 @@ sub run ($) {
     ';
     my $handle_old_row_code =
 	(defined($self->{_count}) ? '$last_fref->[' . $count_coli . '] = $count;' . "\n" : '') .
-	'&$write_fastpath_sub($last_fref);' . "\n";
+	'&$write_fastpath_sub($last_fref) if ($#{$last_fref} != -1);' . "\n";
 
     my $loop_code = q'
 	while ($fref = &$read_fastpath_sub()) {
@@ -287,7 +295,7 @@ sub run ($) {
 
 =head1 AUTHOR and COPYRIGHT
 
-Copyright (C) 1991-2008 by John Heidemann <johnh@isi.edu>
+Copyright (C) 1991-2012 by John Heidemann <johnh@isi.edu>
 
 This program is distributed under terms of the GNU general
 public license, version 2.  See the file COPYING
