@@ -2,7 +2,9 @@
 
 #
 # Fsdb::IO::Reader.pm
-# Copyright (C) 2005-2019 by John Heidemann <johnh@isi.edu>
+# $Id$
+#
+# Copyright (C) 2005 by John Heidemann <johnh@isi.edu>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License,
@@ -15,7 +17,7 @@
 # 
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
-# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+# 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 #
 
 
@@ -28,13 +30,13 @@ Fsdb::IO::Reader - handle formatting reading from a fsdb file (handle) or queue
 =cut
 
 @ISA = qw(Fsdb::IO);
-($VERSION) = 1.1;
+($VERSION) = ('$Revision$' =~ m/(\d+)/);
 
 use strict;
 use IO::File;
 use Carp;
-use IO::Uncompress::AnyUncompress;
-use IPC::Open2;
+use threads;
+# use threads::shared;
 
 use Fsdb::IO;
 
@@ -57,11 +59,10 @@ Sample code reading an input stream:
 =head2 new
 
     $fsdb = new Fsdb::IO::Reader(-file => $filename);
-    $fsdb = new Fsdb::IO::Reader(-header => "#fsdb -F t foo bar", -fh => $file_handle);
+    $fsdb = new Fsdb::IO::Reader(-header => "#h -Ft foo bar", -fh => $file_handle);
 
 Creates a new reader object from FILENAME.
-(FILENAME can also be a IO::Handle object,
-or an hdfs: file.)
+(FILENAME can also be a IO::Handle object.)
 Always succeeds, but 
 check the C<error> method to test for failure.
 
@@ -75,8 +76,6 @@ C<-file>, C<-header>.
 
 =item B<-file FILENAME>
 Open and read the given filename.
-Special filename "-" is standard input,
-and files with hdfs: are read from Hadoop (but not with directory aggregation).
 
 =item B<-comment_handler $ref>
 
@@ -95,16 +94,7 @@ where the one argument will be a string with the unparsed comment
 
 By default, or if $ref is undef, comments are consumed.
 
-A typical handler if you have an output Fsdb stream is:
-
-    sub { $out->write_raw(@_); };
-
-(That is the code created by  L<Fsdb::Filter::create_pass_comments_sub>.)
-
-There are several support routines to handle comments in a pipeline;
-see L<Fsdb::Filter::create_pass_comments_sub>,
-L<Fsdb::Filter::create_tolerant_pass_comments_sub>,
-L<Fsdb::Filter::create_delay_comments_sub>.
+TODO: need to support buffered comments.
 
 =back
 
@@ -128,16 +118,12 @@ sub new {
     #
     # setup:    
     if (! ($self->{_fh} || $self->{_queue})) {
-	$self->{_error} //= "Fsdb::IO::Reader: cannot setup filehandle";
+	$self->{_error} = "cannot setup filehandle";
 	return $self;
     };
-    if ($self->{_fh} && ref($self->{_fh}) eq 'IO::Pipe') {
-	# don't do this if we're IO::Pipe::End, since it's already been done
-	$self->{_fh}->reader();
-    };
     $self->comment_handler_to_sub;
     # Note: reader/writer difference: readers have io subs before headers; writers only after.
-    $self->create_io_subs();
+    $self->create_io_subs;
 
     if (!defined($self->{_headerrow})) {
 	# get the header from the file (must not have been specified by the user)
@@ -147,16 +133,12 @@ sub new {
     if (defined($self->{_headerrow})) {
 	$self->{_header_set} = 1;   # go read-only
 	# rebuild io subs in case the fscode changed
-	$self->create_io_subs();
-    } else {
-	$self->{_error} = "no header line";
-	return $self;
+	$self->create_io_subs;
     };
 
     return $self;
 }
 
-
 =head2 config_one
 
 documented in new
@@ -168,26 +150,11 @@ sub config_one {
 	shift @$aaref;
 	my($file) = shift @$aaref;
 	my $fh;
-	my $mode = $self->default_binmode();
 	if ($file eq '-') {
-	    $fh = new IO::Handle;
-	    $fh->fdopen(fileno(STDIN),"<");
-	    binmode $fh, $mode;
-	} elsif ($file =~ /^hdfs:/) {
-            my($hdfs_fh, $compression_fh);
-            $self->{_hdfs_reader_pid} = open($hdfs_fh, '-|', "hdfs", "-cat", $file);
-            my $decompressor = Fsdb::IO::_find_filename_decompressor($file);
-            if ($decompressor) {
-                $self->{_compression_pid} = open2($compression_fh, $hdfs_fh, $decompressor);
-            };
-            $fh = $compression_fh // $hdfs_fh;
-        } else {
-            my $decompressor = Fsdb::IO::_find_filename_decompressor($file);
-            if ($decompressor) {
-                $self->{_compression_pid} = open($fh, '-|', $decompressor, $file);
-            } else {
-                $fh = new IO::File $file, "<$mode";
-            };
+	     $fh = new IO::Handle;
+	     $fh->fdopen(fileno(STDIN),"r");
+	} else {
+	     $fh = new IO::File $file, "r";
 	};
 	if ($fh) {
 	    $self->{_fh} = $fh;
@@ -205,7 +172,7 @@ sub config_one {
 
 =head2 comment_handler_to_sub;
 
-internal use only: parses and sets up the comment handle callback.
+interal use only: parses and sets up the comment hanlder callback.
 (At input, _comment_sub is as given by -comment_handler,
 but at exit it is always an anon function.
 
@@ -231,39 +198,25 @@ sub comment_handler_to_sub {
     };
 }
 
-=head2 _enable_compression
-
-    $self->_enable_compression
-
-internal use only: switch from uncompressed to compressed.
-
-=cut
-sub _enable_compression($) {
-    my($self) = @_;
-    return if (!$self->{_compression});
-
-    my $phy_fh = $self->{_fh};
-    binmode($phy_fh, ":raw");
-    $self->{_fh} = new IO::Uncompress::AnyUncompress $phy_fh
-	or croak "Fsdb::IO::Reader: cannot switch to compression " . $self->{_compression};
-    # xxx: we now should push our encoding onto this new fh,
-    # but not clear how IO::Uncompress handles that.
-}
-
 
 =head2 create_io_subs
 
-    $self->create_io_subs()
+    $self->create_io_subs
 
 internal use only: create a thunk that returns rowobjs.
 
 =cut
-sub create_io_subs() {
+sub create_io_subs {
     my($self) = @_;
     return if ($self->{_error});
     croak "confusion: too many IO sources" if (defined($self->{_fh}) && defined($self->{_queue}));
-    if (defined($self->{_fh})) {
-	$self->_enable_compression() if ($self->{_compression} && $self->{_header_set});
+    if (defined($self->{_queue})) {
+	# data is preformatted from a queue
+	my $queue = $self->{_queue};
+	$self->{_read_rowobj_sub} = sub {
+	    return $queue->dequeue;
+	};
+    } elsif (defined($self->{_fh})) {
 	# need to unserialize data from a file handle
 	if ($self->{_rscode} eq 'D') {
 	    #
@@ -330,12 +283,6 @@ sub create_io_subs() {
 	} else {
 	    croak "undefined rscode " . $self->{_rscode} . "\n";
 	};
-    } elsif (defined($self->{_queue})) {
-	# data is preformatted from a queue
-	my $queue = $self->{_queue};
-	$self->{_read_rowobj_sub} = sub {
-	    return $queue->dequeue;
-	};
     } else {
 	croak "confusion: no IO source\n";
     };
@@ -566,7 +513,7 @@ sub fastpath_ok {
 
 Return an anonymous sub that does read fast-path when called.
 This code stub returns a new $aref
-corresponding with a data line, 
+correponding with a data line, 
 and handles comments as specified by -comment_handler
 
 =cut
